@@ -87,40 +87,39 @@ test_that("get_coastal_forecast() stops if the state is recognised", {
 context("parse_coastal_forecast()")
 
 # Test that parse_coastal_forecast() returns a data frame with 19 columns
-test_that("parse_coastal_forecast returns at most 22 columns",
-          {
-            skip_on_cran()
-            download.file(
-              url = "ftp://ftp.bom.gov.au/anon/gen/fwo/IDN11001.xml",
-              destfile = file.path(
-                tempdir(),
-                basename("ftp://ftp.bom.gov.au/anon/gen/fwo/IDN11001.xml")
-              ),
-              mode = "wb"
-            )
-            bom_forecast <-
-              parse_coastal_forecast(state = "NSW", filepath = tempdir())
-            expect_lte(ncol(bom_forecast), 22)
-            expect_equal(bom_forecast[["state_code"]][1], "NSW")
-            expect_is(bom_forecast$index, "factor")
-            expect_is(bom_forecast$product_id, "character")
-            expect_is(bom_forecast$type, "character")
-            expect_is(bom_forecast$state_code, "character")
-            expect_is(bom_forecast$dist_name, "character")
-            expect_is(bom_forecast$pt_1_name, "character")
-            expect_is(bom_forecast$pt_2_name, "character")
-            expect_is(bom_forecast$aac, "character")
-            expect_is(bom_forecast$start_time_local, "POSIXct")
-            expect_is(bom_forecast$end_time_local, "POSIXct")
-            expect_is(bom_forecast$utc_offset, "factor")
-            expect_is(bom_forecast$start_time_utc, "POSIXct")
-            expect_is(bom_forecast$end_time_utc, "POSIXct")
-            expect_is(bom_forecast$forecast_seas, "character")
-            expect_is(bom_forecast$forecast_weather, "character")
-            expect_is(bom_forecast$forecast_winds, "character")
-            expect_is(bom_forecast$forecast_swell1, "character")
-            expect_equal(bom_forecast[["state_code"]][1], "NSW")
-          })
+test_that("parse_coastal_forecast returns at most 22 columns", {
+  skip_on_cran()
+  download.file(
+    url = "ftp://ftp.bom.gov.au/anon/gen/fwo/IDN11001.xml",
+    destfile = file.path(
+      tempdir(),
+      basename("ftp://ftp.bom.gov.au/anon/gen/fwo/IDN11001.xml")
+    ),
+    mode = "wb"
+  )
+  bom_forecast <-
+    parse_coastal_forecast(state = "NSW", filepath = tempdir())
+  expect_lte(ncol(bom_forecast), 22)
+  expect_equal(bom_forecast[["state_code"]][1], "NSW")
+  expect_is(bom_forecast$index, "factor")
+  expect_is(bom_forecast$product_id, "character")
+  expect_is(bom_forecast$type, "character")
+  expect_is(bom_forecast$state_code, "character")
+  expect_is(bom_forecast$dist_name, "character")
+  expect_is(bom_forecast$pt_1_name, "character")
+  expect_is(bom_forecast$pt_2_name, "character")
+  expect_is(bom_forecast$aac, "character")
+  expect_is(bom_forecast$start_time_local, "POSIXct")
+  expect_is(bom_forecast$end_time_local, "POSIXct")
+  expect_is(bom_forecast$utc_offset, "factor")
+  expect_is(bom_forecast$start_time_utc, "POSIXct")
+  expect_is(bom_forecast$end_time_utc, "POSIXct")
+  expect_is(bom_forecast$forecast_seas, "character")
+  expect_is(bom_forecast$forecast_weather, "character")
+  expect_is(bom_forecast$forecast_winds, "character")
+  expect_is(bom_forecast$forecast_swell1, "character")
+  expect_equal(bom_forecast[["state_code"]][1], "NSW")
+})
 
 # Test that parse_coastal_forecast() returns the requested state forecast
 test_that("parse_coastal_forecast() returns the forecast for ACT/NSW", {
@@ -244,6 +243,6 @@ test_that(" Test that parse_coastal_forecast() stops for bad directory", {
 
 test_that(" Test that parse_coastal_forecast() stops if XML provided", {
   skip_on_cran()
-  expect_error(parse_coastal_forecast(state = "AUS", filepath = 
+  expect_error(parse_coastal_forecast(state = "AUS", filepath =
                                        file.path(tempdir(), "IDW11160.xml")))
 })
